Установка СпамоБорца — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- Руководство пользователя »

# Установка СпамоБорца

Возможны несколько вариантов установки:

- с помощью средств ОС;
- из пакета Python с исходном кодом/бинарного пакета;
- из репозитория.

## С помощью средств ОС

В данный момент пакет СпамоБорца еще не включен ни в одну ОС.

## Установка из пакета

Предварительно необходимо установить python 2.5 или 2.6, а также setuptools. Обычно эти пакеты уже установлены в ОС.

Установка из пакета выполняется просто:

    easy_install spamfighter

Данная команда автоматически обращается к Python Package Index (PyPI), находит последнюю версию СпамоБорца, скачивает и устанавливает её. Также можно скачать пакет СпамоБорца с сайта http://spam-fighter.ru/ и установить его с помощью easy_install (egg) или просто распаковав архив (binary distribution).

Еще одним способом установки является скачивание исходного пакета Python (source distribution) и установка вручную:

    python setup.py build
    python setup.py install

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- Руководство пользователя »